California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 002 - STATE RESERVE POLICY. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1372629 | THINK LONG COMMITTEE, INC., SPONSORED BY NICOLAS BERGGRUEN INSTITUTE TRUST, SUPPORTING PROPOSITIONS 1 & 2 (NON-PROFIT 501(C)(4)) | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1358148 | SOUTHERN CALIFORNIA DISTRICT COUNCIL OF LABORERS ISSUES PAC - YES ON PROPS 1 AND 2 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1372412 | CALIFORNIA WATER ASSOCIATION POLITICAL ISSUES COMMITTEE- YES ON PROPOSITIONS 1 & 2 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1358725 | LABORERS PACIFIC SOUTHWEST REGIONAL ORGANIZING COALITION ISSUES PAC - YES ON PROPS 1 AND 2 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1272719 | CONSERVATION ACTION FUND - YES ON PROPOSITION 1 AND 2 - SPONSORED BY CONSERVATION ORGANIZATIONS | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1372785 | WESTERN PLANT HEALTH ASSOCIATION, SUPPORTING PROPOSITIONS 1 AND 2 ( NON-PROFIT 501 (C) (6) ) | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1373184 | CALIFORNIA FORWARD, YES ON PROPOSITION 2 ( NONPROFIT 501 (C) (3) ) | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1238760 | CALIFORNIA TRUST FOR PUBLIC LAND ACTION FUND, THE | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1373393 | JAMUL INDIAN VILLAGE FOR PROPOSITIONS 1 AND 2 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1356004 | LEVINE BALLOT ISSUE COMMITTEE, ELEVATE CALIFORNIA: MARC | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
761010 | CALIFORNIA BUSINESS POLITICAL ACTION COMMITTEE, SP0NSORED BY THE CALIFORNIA CHAMBER OF COMMERCE (AKA CALBUSPAC) - YES ON 1 & 2 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1310030 | CALIFORNIA FORWARD ISSUES ACTION FUND - YES ON PROPOSITION 2 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1343257 | BROWN; YES ON PROPS 1 AND 2 A BIPARTISAN COALITION OF BUSINESS LABOR REPUBLICANS DEMOCRATS AND GOVERNOR | SUPPORT